@@ -7,4 +7,9 @@ class LoadType(Enum):
     clazz = "class"
 
 
+class DecoratorVal(Enum):
+    flg = "_load_flg"
+    order = "_load_order"
+
+
 Class_Or_Func = TypeVar("Class_Or_Func", Type[Any], Callable)
