@@ -2,7 +2,7 @@ __all__ = "load_config"
 
 from typing import Callable, Optional
 
-from autoload._globals import Class_Or_Func
+from autoload._globals import Class_Or_Func, DecoratorVal
 
 
 def load_config(
@@ -10,8 +10,8 @@ def load_config(
 ) -> Callable[[Class_Or_Func], Class_Or_Func]:
     def decorator(resource: Class_Or_Func):
         if order:
-            setattr(resource, "_load_order", order)
-        setattr(resource, "_load_flg", load)
+            setattr(resource, DecoratorVal.order.value, order)
+        setattr(resource, DecoratorVal.flg.value, load)
         return resource
 
     return decorator
